[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Module Hierarchy

- tlslite: TLS Lite is a free python library that implements SSL and TLS.
  - tlslite.api
  - tlslite.basedb: Base class for SharedKeyDB and VerifierDB.
  - tlslite.checker: Class for post-handshake certificate checking.
  - tlslite.constants: Constants used in various places.
  - tlslite.errors: Exception classes.
  - tlslite.handshakesettings: Class for setting handshake parameters.
  - tlslite.integration: Classes for integrating TLS Lite with other packages.
    - tlslite.integration.asyncstatemachine: A state machine for using TLS Lite with asynchronous I/O.
    - tlslite.integration.clienthelper: A helper class for using TLS Lite with stdlib clients (httplib, xmlrpclib, imaplib, poplib).
    - tlslite.integration.httptlsconnection: TLS Lite + httplib.
    - tlslite.integration.imap4_tls: TLS Lite + imaplib.
    - tlslite.integration.pop3_tls: TLS Lite + poplib.
    - tlslite.integration.smtp_tls: TLS Lite + smtplib.
    - tlslite.integration.tlsasyncdispatchermixin: TLS Lite + asyncore.
    - tlslite.integration.tlssocketservermixin: TLS Lite + SocketServer.
    - tlslite.integration.xmlrpcserver: xmlrpcserver.py - simple XML RPC server supporting TLS
    - tlslite.integration.xmlrpctransport: TLS Lite + xmlrpclib.
  - tlslite.mathtls: Miscellaneous helper functions.
  - tlslite.messages: Classes representing TLS messages.
  - tlslite.session: Class representing a TLS session.
  - tlslite.sessioncache: Class for caching TLS sessions.
  - tlslite.tlsconnection: MAIN CLASS FOR TLS LITE (START HERE!).
  - tlslite.tlsrecordlayer: Helper class for TLSConnection.
  - tlslite.utils: Toolkit for crypto and other stuff.
    - tlslite.utils.aes: Abstract class for AES.
    - tlslite.utils.asn1parser: Class for parsing ASN.1
    - tlslite.utils.cipherfactory: Factory functions for symmetric cryptography.
    - tlslite.utils.codec: Classes for reading/writing binary data (such as TLS records).
    - tlslite.utils.compat: Miscellaneous functions to mask Python version differences.
    - tlslite.utils.cryptomath: cryptomath module
    - tlslite.utils.datefuncs
    - tlslite.utils.keyfactory: Factory functions for asymmetric cryptography.
    - tlslite.utils.openssl_aes: OpenSSL/M2Crypto AES implementation.
    - tlslite.utils.openssl_rc4: OpenSSL/M2Crypto RC4 implementation.
    - tlslite.utils.openssl_rsakey: OpenSSL/M2Crypto RSA implementation.
    - tlslite.utils.openssl_tripledes: OpenSSL/M2Crypto 3DES implementation.
    - tlslite.utils.pem
    - tlslite.utils.pycrypto_aes: PyCrypto AES implementation.
    - tlslite.utils.pycrypto_rc4: PyCrypto RC4 implementation.
    - tlslite.utils.pycrypto_rsakey: PyCrypto RSA implementation.
    - tlslite.utils.pycrypto_tripledes: PyCrypto 3DES implementation.
    - tlslite.utils.python_aes: Pure-Python AES implementation.
    - tlslite.utils.python_rc4: Pure-Python RC4 implementation.
    - tlslite.utils.python_rsakey: Pure-Python RSA implementation.
    - tlslite.utils.rc4: Abstract class for RC4.
    - tlslite.utils.rijndael: A pure python (slow) implementation of rijndael with a decent interface
    - tlslite.utils.rsakey: Abstract class for RSA.
    - tlslite.utils.tackwrapper
    - tlslite.utils.tripledes: Abstract class for 3DES.
  - tlslite.verifierdb: Class for storing SRP password verifiers.
  - tlslite.x509: Class representing an X.509 certificate.
  - tlslite.x509certchain: Class representing an X.509 certificate chain.